import { TranslateLoader } from '@ngx-translate/core';
import { Observable } from 'rxjs';
import { NativeService } from '@ucap-webmessenger/native';

export class TranslateLoaderService implements TranslateLoader {
  textDecoder: TextDecoder;

  constructor(
    private nativeService: NativeService,
    private prefix: string = '/assets/i18n/',
    private suffix: string = '.json'
  ) {
    this.textDecoder = new TextDecoder('utf-8');
  }

  /**
   * Gets the translations from the server
   */
  public getTranslation(lang: string): Observable<any> {
    return new Observable<any>(subscriber => {
      this.nativeService
        .readFile(`${this.prefix}${lang}${this.suffix}`)
        .then(buffer => {
          const s = this.textDecoder.decode(buffer);
          const t = JSON.parse(s);
          subscriber.next(t);
        })
        .catch(reason => {
          subscriber.error(reason);
        })
        .finally(() => {
          subscriber.complete();
        });
    });
  }
}
