import {
  Component,
  OnInit,
  Input,
  Output,
  EventEmitter,
  ElementRef,
  AfterViewInit,
  Inject
} from '@angular/core';
import { Info, MassTextEventJson } from '@ucap-webmessenger/protocol-event';
import { NGXLogger } from 'ngx-logger';
import { StatusCode } from '@ucap-webmessenger/api';
import moment from 'moment';
import { NativeService, UCAP_NATIVE_SERVICE } from '@ucap-webmessenger/native';

@Component({
  selector: 'ucap-chat-message-box-mass',
  templateUrl: './mass.component.html',
  styleUrls: ['./mass.component.scss']
})
export class MassComponent implements OnInit, AfterViewInit {
  @Input()
  message: Info<MassTextEventJson>;

  @Output()
  massDetail = new EventEmitter<number>();

  content: string;
  eventMassSeq: number;
  detailButteonShow = true;

  moment = moment;

  constructor(
    private logger: NGXLogger,
    private elementRef: ElementRef,
    @Inject(UCAP_NATIVE_SERVICE) private nativeService: NativeService
  ) {}

  ngOnInit() {
    try {
      if (StatusCode.Success === this.message.sentMessageJson.statusCode) {
        this.content = this.message.sentMessageJson.content;
      } else {
        this.content =
          this.message.sentMessageJson.errorMessage || '[Error] System Error!!';
        this.detailButteonShow = false;
      }

      if (!!this.message.sentMessageJson.massSeq) {
        this.eventMassSeq = this.message.sentMessageJson.massSeq;
      } else {
        this.detailButteonShow = false;
      }
    } catch (e) {
      this.logger.error(e);
      this.detailButteonShow = false;
    }
  }

  ngAfterViewInit(): void {
    if (
      !!this.elementRef.nativeElement &&
      !!this.elementRef.nativeElement.querySelector('a')
    ) {
      const elements = this.elementRef.nativeElement.querySelectorAll('a');
      elements.forEach(element => {
        element.addEventListener('click', this.onClickEvent.bind(this));
      });
    }
  }

  onClickEvent(event: MouseEvent) {
    this.nativeService.openDefaultBrowser(
      (event.target as HTMLAnchorElement).text
    );
  }

  onClickDetailView() {
    this.massDetail.emit(this.eventMassSeq);
  }
}
